# Changelog

## [0.5.1](https://github.com/PastorD/wcheck/compare/v0.5.0...v0.5.1) (2026-01-14)


### Features

* fetch and pull in tui ([1bc5dfe](https://github.com/PastorD/wcheck/commit/1bc5dfe26c44f04610715ab19c26f66f0b889186))
* run git actions in the background ([5f866fb](https://github.com/PastorD/wcheck/commit/5f866fb8b8ff66676b182b24c5f52de4afe7d73c))


### Bug Fixes

* another fix attempt to auto-release ([6442d44](https://github.com/PastorD/wcheck/commit/6442d44c7c51213abdbcfdebef5c66d2c4dc82bf))
* fix release workflow ([b16ce0e](https://github.com/PastorD/wcheck/commit/b16ce0e9c148b0878951e28f1b9c2814d1b6e6d8))
* id token ([e61edeb](https://github.com/PastorD/wcheck/commit/e61edeb116bb27b3a537c9acdb5a61a98512736f))
* id token ([56cab6d](https://github.com/PastorD/wcheck/commit/56cab6d3392c986664f0f82a550b56e347baf2e0))

## [0.5.0](https://github.com/PastorD/wcheck/compare/v0.2.0...v0.5.0) (2026-01-14)


### Features

* add github actions ([0a1214a](https://github.com/PastorD/wcheck/commit/0a1214a6c994eda182821306b355be3fdd909d83))
* add similar projects ([1ee8915](https://github.com/PastorD/wcheck/commit/1ee8915c66b78560f867c346a5608ffe8360489d))
* compare multiple local workspaces ([5e75084](https://github.com/PastorD/wcheck/commit/5e750841447924f1260bd75dc4f335608cbb1333))
* tui ([511b84b](https://github.com/PastorD/wcheck/commit/511b84b54363dd971709d370db4e62eccf9d4e7b))


### Bug Fixes

* docs url ([98074c4](https://github.com/PastorD/wcheck/commit/98074c40c75786f388841a67d9658394ddaf96f1))


## [0.2.0](https://github.com/PastorD/wcheck/compare/v0.1.0...v0.2.0) (2026-01-11)


### Features

* add github actions ([0a1214a](https://github.com/PastorD/wcheck/commit/0a1214a6c994eda182821306b355be3fdd909d83))


## 0.1.0 (2026-01-11)

Initial release.
